@@ -64,6 +64,13 @@ class ACodeChecker(
     def all_files(self) -> bool:
         return self.args.all_files
 
+    @cached_property
+    def binaries(self) -> Dict[str, str]:
+        return dict(
+            binary.split(":")
+            for binary
+            in self.args.binary)
+
     @cached_property
     def disabled_checks(self):
         disabled = {}
@@ -89,10 +96,11 @@ class ACodeChecker(
     def changelog_class(self) -> Type["abstract.AChangelogCheck"]:
         raise NotImplementedError
 
-    @property
+    @cached_property
     def check_kwargs(self) -> Mapping:
         return dict(
             fix=self.fix,
+            binaries=self.binaries,
             loop=self.loop,
             pool=self.pool)
 
@@ -220,13 +228,13 @@ class ACodeChecker(
         parser.add_argument("-a", "--all_files", action="store_true")
         parser.add_argument("-m", "--matching", action="append")
         parser.add_argument("-x", "--excluding", action="append")
+        parser.add_argument("-b", "--binary", action="append")
         parser.add_argument("-s", "--since")
         parser.add_argument("--extensions_build_config")
 
     async def check_changelog(self):
         for changelog in self.changelog:
-            errors = await changelog.errors
-            if errors:
+            if errors := await changelog.errors:
                 self.error("changelog", errors)
             else:
                 self.succeed(
@@ -257,8 +265,7 @@ class ACodeChecker(
 
     async def check_extensions_registered(self) -> None:
         """Check for glint issues."""
-        errors = await self.extensions.registration_errors
-        if errors:
+        if errors := await self.extensions.registration_errors:
             self.error("extensions_registered", errors)
         else:
             self.succeed(
